<template>
  <el-form :model="form" label-width="100px">
    <el-form-item label="实际保养人">
      <el-input
        v-model="form.maintenanceActuallyName"
        placeholder="请输入实际保养人"
      ></el-input>
    </el-form-item>
    <el-form-item label="实际保养日期">
      <el-date-picker
        v-model="form.maintenanceActuallyTime"
        placeholder="请选择实际保养日期"
        format="YYYY-MM-DD HH:mm:ss"
        value-format="YYYY-MM-DD HH:mm:ss"
        type="datetime"
        clearable
        style="width: 100%"
      />
    </el-form-item>
    <el-form-item label="保养结果">
      <el-select v-model="form.maintenanceResult" placeholder="请选择保养结果">
        <el-option label="完好" :value="1"></el-option>
        <el-option label="维修" :value="0"></el-option>
      </el-select>
    </el-form-item>
  </el-form>
</template>

<script setup>
import useFormData from "@/hooks/useFormData";
import dayjs from "dayjs";
import useUserStore from "@/store/modules/user";

defineOptions({
  name: "保养表单",
});

const userStore = useUserStore();
const { form, resetForm } = useFormData({
  maintenanceActuallyName: undefined, // 实际保养人
  maintenanceActuallyTime: undefined, // 实际保养日期
  maintenanceResult: undefined, // 保养结果
});

const setForm = (data) => {
  form.maintenanceActuallyName =
    data.maintenanceActuallyName ?? userStore.nickName;
  form.maintenanceActuallyTime =
    dayjs(data.maintenanceActuallyTime).format("YYYY-MM-DD HH:mm:ss") ??
    dayjs().format("YYYY-MM-DD HH:mm:ss");
  form.maintenanceResult = data.maintenanceResult;
};

const getForm = () => {
  return form;
};

defineExpose({
  getForm,
  setForm,
  resetForm,
});
</script>

<style lang="scss" scoped></style>
